@@ -6,7 +6,7 @@ ATTACHMENTS_TMP_PATH = r'C:\Temp\\'
 
 
 def send_mail(address_to: str, address_cc: str, mail_subject: str, mail_body: str,
-              attachments_list: list = None, address_from: str = None):
+              attachments_list: list = None, address_from: str = None) -> None:
     """
     Function to send mail using Outlook without opening it.
     :param address_to: recipient address list 'John@John.com;Ann@Ann.com'
@@ -32,7 +32,7 @@ def send_mail(address_to: str, address_cc: str, mail_subject: str, mail_body: st
     mail.Send()
 
 
-def delete_files(file_paths: list):
+def delete_files(file_paths: list) -> None:
     """
     Function to delete temporary files after mail was sent.
     :param file_paths: list of paths of attachments ['path1','path2']
